/// <reference types="mapbox-gl" />
import type { ProjectionSpecification, ViewState, ViewStateChangeEvent, MapboxOptions, MapboxStyle, ImmutableLike, LngLatBoundsLike, FitBoundsOptions, MapMouseEvent, MapLayerMouseEvent, MapLayerTouchEvent, MapWheelEvent, MapDataEvent, MapboxEvent, ErrorEvent, MapboxMap } from '../utils/types';
export declare type MapboxProps = Omit<MapboxOptions, 'center' | 'accessToken' | 'container' | 'style' | 'bounds' | 'fitBoundsOptions'> & ViewState & {
    mapboxAccessToken?: string;
    /** Camera options used when constructing the Map instance */
    initialViewState?: ViewState & {
        bounds?: LngLatBoundsLike;
        fitBoundsOptions?: FitBoundsOptions;
    };
    /** If provided, render into an external WebGL context */
    gl?: WebGLRenderingContext;
    /** Aternative way to specify camera state */
    viewState?: ViewState;
    /** Mapbox style */
    mapStyle?: string | MapboxStyle | ImmutableLike;
    /** Enable diffing when the map style changes */
    styleDiffing?: boolean;
    /** Default layers to query on pointer events */
    interactiveLayerIds?: string[];
    /** The projection the map should be rendered in */
    projection?: ProjectionSpecification | string;
    /** CSS cursor */
    cursor?: string;
    onMouseDown?: (e: MapLayerMouseEvent) => void;
    onMouseUp?: (e: MapLayerMouseEvent) => void;
    onMouseOver?: (e: MapLayerMouseEvent) => void;
    onMouseMove?: (e: MapLayerMouseEvent) => void;
    onClick?: (e: MapLayerMouseEvent) => void;
    onDblClick?: (e: MapLayerMouseEvent) => void;
    onMouseEnter?: (e: MapLayerMouseEvent) => void;
    onMouseLeave?: (e: MapLayerMouseEvent) => void;
    onMouseOut?: (e: MapLayerMouseEvent) => void;
    onContextMenu?: (e: MapLayerMouseEvent) => void;
    onWheel?: (e: MapWheelEvent) => void;
    onTouchStart?: (e: MapLayerTouchEvent) => void;
    onTouchEnd?: (e: MapLayerTouchEvent) => void;
    onTouchMove?: (e: MapLayerTouchEvent) => void;
    onTouchCancel?: (e: MapLayerTouchEvent) => void;
    onMoveStart?: (e: ViewStateChangeEvent) => void;
    onMove?: (e: ViewStateChangeEvent) => void;
    onMoveEnd?: (e: ViewStateChangeEvent) => void;
    onDragStart?: (e: ViewStateChangeEvent) => void;
    onDrag?: (e: ViewStateChangeEvent) => void;
    onDragEnd?: (e: ViewStateChangeEvent) => void;
    onZoomStart?: (e: ViewStateChangeEvent) => void;
    onZoom?: (e: ViewStateChangeEvent) => void;
    onZoomEnd?: (e: ViewStateChangeEvent) => void;
    onRotateStart?: (e: ViewStateChangeEvent) => void;
    onRotate?: (e: ViewStateChangeEvent) => void;
    onRotateEnd?: (e: ViewStateChangeEvent) => void;
    onPitchStart?: (e: ViewStateChangeEvent) => void;
    onPitch?: (e: ViewStateChangeEvent) => void;
    onPitchEnd?: (e: ViewStateChangeEvent) => void;
    onBoxZoomStart?: (e: ViewStateChangeEvent) => void;
    onBoxZoomEnd?: (e: ViewStateChangeEvent) => void;
    onBoxZoomCancel?: (e: ViewStateChangeEvent) => void;
    onResize?: (e: MapboxEvent) => void;
    onLoad?: (e: MapboxEvent) => void;
    onRender?: (e: MapboxEvent) => void;
    onIdle?: (e: MapboxEvent) => void;
    onError?: (e: ErrorEvent) => void;
    onRemove?: (e: MapboxEvent) => void;
    onData?: (e: MapDataEvent) => void;
    onStyleData?: (e: MapDataEvent) => void;
    onSourceData?: (e: MapDataEvent) => void;
};
/**
 * A wrapper for mapbox-gl's Map class
 */
export default class Mapbox {
    private _map;
    props: MapboxProps;
    private _renderTransform;
    private _internalUpdate;
    private _inRender;
    private _hoveredFeatures;
    private _moved;
    private _zoomed;
    private _pitched;
    private _rotated;
    private _nextProps;
    constructor(props: MapboxProps);
    get map(): MapboxMap;
    get viewState(): ViewState;
    setProps(props: MapboxProps): void;
    initialize(container: HTMLDivElement): void;
    destroy(): void;
    redraw(): void;
    _updateViewState(nextProps: MapboxProps, triggerEvents: boolean): boolean;
    _updateSettings(nextProps: MapboxProps, currProps: MapboxProps): boolean;
    _updateStyle(nextProps: MapboxProps, currProps: MapboxProps): boolean;
    _updateHandlers(nextProps: MapboxProps, currProps: MapboxProps): boolean;
    _onEvent: (e: MapboxEvent) => void;
    _onError: (e: ErrorEvent) => void;
    _updateHover(e: MapMouseEvent): void;
    _onPointerEvent: (e: MapLayerMouseEvent | MapLayerTouchEvent) => void;
    _onCameraEvent: (e: ViewStateChangeEvent) => void;
    _fireEvent(baseFire: Function, event: string | MapboxEvent, properties?: object): any;
    _render(baseRender: Function, arg: number): void;
    _onBeforeRepaint(): void;
}
